Virtual

Struct Virtual 

struct Virtual;
Marker component grouping all of the virtual pieces of the trains together. The virtual pieces store only the information needed to provide visual feedback to the user, all other information is stored in CurrentPlacingTrain.